.. _install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
replace with the service it implements service, code-named ustackdocstheme, on the controller node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
.. (add the appropriate services here and further notes)

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 2

   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
